@@ -12,7 +12,7 @@ import xmltodict
 
 
 def parse_file(filename):
-    with open(filename, 'r') as fd:
+    with open(filename, "r") as fd:
         lines = fd.readlines()
 
     data = []
@@ -26,35 +26,35 @@ def parse_file(filename):
             xml.append(line)
         else:
             data.append(line)
-    metadata = dict(**xmltodict.parse('\n'.join(xml)))
+    metadata = dict(**xmltodict.parse("\n".join(xml)))
 
-    data = ''.join(data)
+    data = "".join(data)
     m = hashlib.md5(data.encode())
     md5sum = m.hexdigest()
 
     return md5sum, metadata
 
 
-def test_one(filename='data/slako/3ob/3ob-3-1/Br-Br.skf'):
+def test_one(filename="data/slako/3ob/3ob-3-1/Br-Br.skf"):
     md5sum, metadata = parse_file(filename)
 
     # print(f'md5sum = {md5sum}')
     # print(json.dumps(metadata, indent=4))
 
-    general = metadata['Documentation']['General']
-    if general['Md5sum'] != md5sum:
-        print('md5 checksums differ!')
+    general = metadata["Documentation"]["General"]
+    if general["Md5sum"] != md5sum:
+        print("md5 checksums differ!")
 
-    compatibility = general['Compatibility']
-    partners = compatibility['Partner']
+    compatibility = general["Compatibility"]
+    partners = compatibility["Partner"]
     for partner in partners:
         print(f"{partner['@Identifier']:>9} {partner['Md5sum']}")
 
-    SK_table = metadata['Documentation']['SK_table']
+    SK_table = metadata["Documentation"]["SK_table"]
     print(f"Shells = {SK_table['Basis']['Shells']}")
 
 
-def analyze_directory(root='data/slako'):
+def analyze_directory(root="data/slako"):
     """Find all the Slater-Koster files under a given directory
     and analyze their metadata.
     """
@@ -63,43 +63,43 @@ def analyze_directory(root='data/slako'):
 
     comments = []
     metadata = {
-        'bad_md5s': {},
-        'same': {},
-        'parameterizations': [],
-        'potentials': {},
+        "bad_md5s": {},
+        "same": {},
+        "parameterizations": [],
+        "potentials": {},
     }
-    bad = metadata['bad_md5s']
-    same = metadata['same']
-    parameterizations = metadata['parameterizations']
-    all_potentials = metadata['potentials']
+    bad = metadata["bad_md5s"]
+    same = metadata["same"]
+    parameterizations = metadata["parameterizations"]
+    all_potentials = metadata["potentials"]
 
-    sk_files = root.glob('**/*.skf')
+    sk_files = root.glob("**/*.skf")
     for path in sk_files:
         # Assume the parent directory is the parameterization + version
         # and grandparent is the parameterization.
         parent = path.parent
         # Handle the ob2 files...
-        if parent.name == 'split' or parent.name == 'shift':
+        if parent.name == "split" or parent.name == "shift":
             continue
-        if parent.name == 'base':
+        if parent.name == "base":
             parent = parent.parent
         grandparent = parent.parent
         parameterization = grandparent.name
-        version = '.'.join(parent.name.split('-')[1:])
+        version = ".".join(parent.name.split("-")[1:])
         if parameterization not in parameterizations:
             parameterizations.append(parameterization)
 
         md5sum, data = parse_file(path)
 
-        data = data['Documentation']
-        general = data['General']
+        data = data["Documentation"]
+        general = data["General"]
 
-        data['parameterization'] = parameterization
-        data['version'] = version
-        data['filename'] = str(path)
+        data["parameterization"] = parameterization
+        data["version"] = version
+        data["filename"] = str(path)
 
         if md5sum in all_potentials:
-            if 'filename' not in all_potentials[md5sum]:
+            if "filename" not in all_potentials[md5sum]:
                 comments.append(
                     f"{path} metadata already exists for {md5sum} "
                     "but there is no filename !?!"
@@ -109,85 +109,72 @@ def analyze_directory(root='data/slako'):
         else:
             all_potentials[md5sum] = data
 
-        if general['Md5sum'] != md5sum:
-            md5 = general['Md5sum']
+        if general["Md5sum"] != md5sum:
+            md5 = general["Md5sum"]
 
-            data['md5 mismatch'] = True
+            data["md5 mismatch"] = True
             bad[md5] = md5sum
-            comments.append(f'{path} md5 checksums differ! {md5} {md5sum}')
+            comments.append(f"{path} md5 checksums differ! {md5} {md5sum}")
         else:
-            data['md5 mismatch'] = False
+            data["md5 mismatch"] = False
 
         if parameterization not in metadata:
             pdata = metadata[parameterization] = {}
         else:
             pdata = metadata[parameterization]
         if version not in pdata:
-            vdata = pdata[version] = {
-                'potentials': {},
-                'sets': []
-            }
+            vdata = pdata[version] = {"potentials": {}, "sets": []}
         else:
             vdata = pdata[version]
-        potentials = vdata['potentials']
-        el1 = general['Element1']
-        if 'Element2' in general:
-            el2 = general['Element2']
+        potentials = vdata["potentials"]
+        el1 = general["Element1"]
+        if "Element2" in general:
+            el2 = general["Element2"]
         else:
             el2 = el1
         # Check the file name
-        if '-' in path.stem:
+        if "-" in path.stem:
             try:
-                tmp1, tmp2 = path.stem.split('_')[0].split('-')
+                tmp1, tmp2 = path.stem.split("_")[0].split("-")
                 if tmp1 != el1 or tmp2 != el2:
-                    comments.append(
-                        f'Element error in {path}: should be {el1}-{el2}'
-                    )
-                data['elements'] = [tmp1, tmp2]
+                    comments.append(f"Element error in {path}: should be {el1}-{el2}")
+                data["elements"] = [tmp1, tmp2]
             except Exception:
-                print(f'Odd filename: {path} -- elements {el1}-{el2}')
-                comments.append(
-                    f'Odd filename: {path} -- elements {el1}-{el2}'
-                )
+                print(f"Odd filename: {path} -- elements {el1}-{el2}")
+                comments.append(f"Odd filename: {path} -- elements {el1}-{el2}")
             # Believe the filename
             potentials[path.stem] = md5sum
         else:
             if path.stem != el1 + el2:
-                print(f'Odd filename: {path} -- elements {el1}-{el2}')
-                comments.append(
-                    f'Odd filename: {path} -- elements {el1}-{el2}'
-                )
+                print(f"Odd filename: {path} -- elements {el1}-{el2}")
+                comments.append(f"Odd filename: {path} -- elements {el1}-{el2}")
             # Believe the elements
-            potentials[f'{el1}-{el2}'] = md5sum
-            data['elements'] = [el1, el2]
+            potentials[f"{el1}-{el2}"] = md5sum
+            data["elements"] = [el1, el2]
 
     # The files that have the same potential
     if len(same) > 0:
-        comments.append('')
-        comments.append('The following files have the same data:')
+        comments.append("")
+        comments.append("The following files have the same data:")
         for f1, md5sum in same.items():
-            f2 = all_potentials[md5sum]['filename']
+            f2 = all_potentials[md5sum]["filename"]
             if Path(f1).parent == Path(f2).parent:
                 # comments.append(f'    {f1} {Path(f2).name}')
                 pass
             else:
-                comments.append(f'    {md5sum} {f1} {f2}')
+                comments.append(f"    {md5sum} {f1} {f2}")
 
     # Check on the bad md5 sums from in the file
-    comments.append('')
+    comments.append("")
     for other, good in bad.items():
-        good_file = Path(all_potentials[good]['filename']).relative_to(root)
+        good_file = Path(all_potentials[good]["filename"]).relative_to(root)
         if other in metadata:
-            other_file = Path(
-                all_potentials[other]['filename']
-            ).relative_to(root)
-            comments.append(
-                f'file {good_file} has the MD5 sum from {other_file}'
-            )
+            other_file = Path(all_potentials[other]["filename"]).relative_to(root)
+            comments.append(f"file {good_file} has the MD5 sum from {other_file}")
         else:
             comments.append(
-                f'file {good_file} has an MD5 sum internally that doesnt '
-                'match anything'
+                f"file {good_file} has an MD5 sum internally that doesnt "
+                "match anything"
             )
 
     return metadata, comments
@@ -203,9 +190,9 @@ def find_sets(metadata, parameterizations):
         pdata = metadata[parameterization]
         version = [*pdata.keys()][0]
         vdata = pdata[version]
-        potentials = vdata['potentials']
+        potentials = vdata["potentials"]
         for stem in potentials.keys():
-            el1, el2 = stem.split('-')
+            el1, el2 = stem.split("-")
             if el1 not in elements:
                 elements.append(el1)
             if el2 not in elements:
@@ -218,9 +205,9 @@ def find_sets(metadata, parameterizations):
         pdata = metadata[parameterization]
         version = [*pdata.keys()][0]
         vdata = pdata[version]
-        potentials = vdata['potentials']
+        potentials = vdata["potentials"]
         for stem in potentials.keys():
-            el1, el2 = stem.split('-')
+            el1, el2 = stem.split("-")
             if el2 not in pairs[el1]:
                 pairs[el1].append(el2)
             if el1 not in pairs[el2]:
@@ -280,56 +267,56 @@ def find_sets(metadata, parameterizations):
         for n_set in sets[len(elements)]:
             result.append(sorted([*n_set]))
 
-    if 'sets' not in metadata:
-        metadata['sets'] = {}
-    key = ' -- '.join(sorted(parameterizations))
-    metadata['sets'][key] = result
+    if "sets" not in metadata:
+        metadata["sets"] = {}
+    key = " -- ".join(sorted(parameterizations))
+    metadata["sets"][key] = result
     return result
 
 
 def partners2(metadata, parameterization):
     """Find the listed partners"""
     pdata = metadata[parameterization]
-    all_potentials = metadata['potentials']
+    all_potentials = metadata["potentials"]
     version = [*pdata.keys()][0]
     vdata = pdata[version]
-    potentials = vdata['potentials']
+    potentials = vdata["potentials"]
 
     for key, md5sum in potentials.items():
-        print(f'\n{key}')
+        print(f"\n{key}")
         data = all_potentials[md5sum]
-        data['partners'] = []
-        general = data['General']
-        if 'Compatibility' not in general:
+        data["partners"] = []
+        general = data["General"]
+        if "Compatibility" not in general:
             print(f"{data['filename']} has no compatibility data")
             continue
-        compatibility = general['Compatibility']
-        for partner in compatibility['Partner']:
-            md5 = partner['Md5sum']
+        compatibility = general["Compatibility"]
+        for partner in compatibility["Partner"]:
+            md5 = partner["Md5sum"]
             if md5 in all_potentials:
-                data['partners'].append(md5)
+                data["partners"].append(md5)
                 tmp = all_potentials[md5]
                 print(
                     f"     {tmp['parameterization']} {tmp['version']} "
                     f"{partner['@Identifier']}"
                 )
-            elif md5 in metadata['bad_md5s']:
-                good_md5 = metadata['bad_md5s'][md5]
-                data['partners'].append(good_md5)
+            elif md5 in metadata["bad_md5s"]:
+                good_md5 = metadata["bad_md5s"][md5]
+                data["partners"].append(good_md5)
                 tmp = all_potentials[good_md5]
                 print(
                     f"     {tmp['parameterization']} {tmp['version']} "
                     f"{partner['@Identifier']}"
                 )
             else:
-                el1 = partner['Element1']
-                if 'Element2' in partner:
-                    el2 = partner['Element2']
+                el1 = partner["Element1"]
+                if "Element2" in partner:
+                    el2 = partner["Element2"]
                 else:
                     el2 = el1
-                if f'{el1}-{el2}' in potentials:
-                    correct_md5 = potentials[f'{el1}-{el2}']
-                    data['partners'].append(correct_md5)
+                if f"{el1}-{el2}" in potentials:
+                    correct_md5 = potentials[f"{el1}-{el2}"]
+                    data["partners"].append(correct_md5)
                     print(
                         f"    {el1}-{el2} {data['filename']} "
                         f"{partner['@Identifier']} "
@@ -337,7 +324,7 @@ def partners2(metadata, parameterization):
                         f"{all_potentials[correct_md5]['elements']}"
                     )
                 else:
-                    correct_md5 = 'unknown'
+                    correct_md5 = "unknown"
                     print(
                         f"    {el1}-{el2} {data['filename']} "
                         f"{partner['@Identifier']} "
@@ -348,55 +335,55 @@ def partners2(metadata, parameterization):
 
 def partners(metadata):
     """Find the listed partners"""
-    all_potentials = metadata['potentials']
+    all_potentials = metadata["potentials"]
 
     for md5sum, data in all_potentials.items():
         data = all_potentials[md5sum]
-        general = data['General']
-        if 'Compatibility' not in general:
+        general = data["General"]
+        if "Compatibility" not in general:
             print(f"{data['filename']} has no compatibility data")
             continue
-        compatibility = general['Compatibility']
+        compatibility = general["Compatibility"]
         partners = []
-        for partner in compatibility['Partner']:
-            md5 = partner['Md5sum']
+        for partner in compatibility["Partner"]:
+            md5 = partner["Md5sum"]
             if md5 in all_potentials:
                 partners.append(md5)
-            elif md5 in metadata['bad_md5s']:
-                good_md5 = metadata['bad_md5s'][md5]
+            elif md5 in metadata["bad_md5s"]:
+                good_md5 = metadata["bad_md5s"][md5]
                 partners.append(good_md5)
             else:
-                parameterization = data['parameterization']
-                version = data['version']
-                el1 = partner['Element1']
-                el2 = partner['Element1']
-                potentials = metadata[parameterization][version]['potentials']
-                if f'{el1}-{el2}' in potentials:
-                    correct_md5 = potentials[f'{el1}-{el2}']
+                parameterization = data["parameterization"]
+                version = data["version"]
+                el1 = partner["Element1"]
+                el2 = partner["Element1"]
+                potentials = metadata[parameterization][version]["potentials"]
+                if f"{el1}-{el2}" in potentials:
+                    correct_md5 = potentials[f"{el1}-{el2}"]
                 else:
-                    correct_md5 = 'unknown'
+                    correct_md5 = "unknown"
                 print(
                     f"    {data['filename']} {partner['@Identifier']} "
                     f"{partner['Md5sum']} {correct_md5} bad partner md5sum"
                 )
                 # pprint.pprint(partner)
-        data['partners'] = partners
+        data["partners"] = partners
 
 
 def list_partners(metadata, parameterization):
     """Find the listed partners"""
     pdata = metadata[parameterization]
-    all_potentials = metadata['potentials']
+    all_potentials = metadata["potentials"]
     version = [*pdata.keys()][0]
     vdata = pdata[version]
-    potentials = vdata['potentials']
+    potentials = vdata["potentials"]
 
     outside = {}
     inside = []
     for key, md5sum in potentials.items():
         data = all_potentials[md5sum]
-        for partner in data['partners']:
-            p_param = all_potentials[partner]['parameterization']
+        for partner in data["partners"]:
+            p_param = all_potentials[partner]["parameterization"]
             if p_param != parameterization:
                 if p_param not in outside:
                     outside[p_param] = []
@@ -412,108 +399,101 @@ def list_partners(metadata, parameterization):
 def create_datafile():
     """Parse the files and get the data needed for the metadata-file"""
     datasets = {
-        '3ob': ['3ob-freq', '3ob-hhmod', '3ob-nhmod', '3ob-ophyd'],
-        'matsci': ['magsil'],
-        'mio': [
-            'chalc', 'hyb', 'miomod-hh', 'miomod-nh', 'tiorg', 'trans3d',
-            'znorg'
-        ],
-        'auorg': [],
-        'borg': [],
-        'halorg': [],
-        'ob2': [],
-        'pbc': [],
-        'siband': [],
-        'rare': []
+        "3ob": ["3ob-freq", "3ob-hhmod", "3ob-nhmod", "3ob-ophyd"],
+        "matsci": ["magsil"],
+        "mio": ["chalc", "hyb", "miomod-hh", "miomod-nh", "tiorg", "trans3d", "znorg"],
+        "auorg": [],
+        "borg": [],
+        "halorg": [],
+        "ob2": [],
+        "pbc": [],
+        "siband": [],
+        "rare": [],
     }
 
     # The result dictionary
     result = {}
 
     # Read in all the potentials
-    metadata, comments = analyze_directory('data/slako')
-    print('\n'.join(comments))
-    print('')
-    all_potentials = metadata['potentials']
+    metadata, comments = analyze_directory("data/slako")
+    print("\n".join(comments))
+    print("")
+    all_potentials = metadata["potentials"]
 
     # Make a list of the sets or elements covered by each combination
-    result['datasets'] = {}
+    result["datasets"] = {}
     for dataset, subsets in datasets.items():
-        result['datasets'][dataset] = {
-            'subsets': subsets,
-            'parent': None,
+        result["datasets"][dataset] = {
+            "subsets": subsets,
+            "parent": None,
         }
         for subset in subsets:
-            result['datasets'][subset] = {
-                'subsets': [],
-                'parent': dataset,
+            result["datasets"][subset] = {
+                "subsets": [],
+                "parent": dataset,
             }
 
         # Create the element sets
         sets = find_sets(metadata, [dataset])
-        result['datasets'][dataset]['element sets'] = sets
+        result["datasets"][dataset]["element sets"] = sets
         for subset in subsets:
             sets = find_sets(metadata, [dataset, subset])
-            result['datasets'][subset]['element sets'] = sets
+            result["datasets"][subset]["element sets"] = sets
 
     # Transfer desired information about each of the potentials
-    result['potentials'] = {}
-    result['pairs'] = {}
+    result["potentials"] = {}
+    result["pairs"] = {}
     for md5sum, data in all_potentials.items():
-        result['potentials'][md5sum] = {
-            'filename': data['filename'],
-            'elements': data['elements'],
-            'datasets': [f"{data['parameterization']}@{data['version']}"]
+        result["potentials"][md5sum] = {
+            "filename": data["filename"],
+            "elements": data["elements"],
+            "datasets": [f"{data['parameterization']}@{data['version']}"],
         }
-        el1, el2 = data['elements']
-        key = f'{el1}-{el2}'
-        if key not in result['pairs']:
-            result['pairs'][key] = [md5sum]
+        el1, el2 = data["elements"]
+        key = f"{el1}-{el2}"
+        if key not in result["pairs"]:
+            result["pairs"][key] = [md5sum]
         else:
-            result['pairs'][key].append(md5sum)
+            result["pairs"][key].append(md5sum)
 
     # Get the maximum angular moment
-    for dataset in result['datasets']:
+    for dataset in result["datasets"]:
         pdata = metadata[dataset]
         version = [*pdata.keys()][0]
         vdata = pdata[version]
-        potentials = vdata['potentials']
+        potentials = vdata["potentials"]
         elements = {}
 
-        pairs = result['datasets'][dataset]['potential pairs'] = {}
+        pairs = result["datasets"][dataset]["potential pairs"] = {}
         for potential, md5sum in potentials.items():
             data = all_potentials[md5sum]
-            el1, el2 = data['elements']
-            pairs[f'{el1}-{el2}'] = {
-                'md5sum': md5sum
-            }
+            el1, el2 = data["elements"]
+            pairs[f"{el1}-{el2}"] = {"md5sum": md5sum}
 
             # Check that this dataset/version is in the list
             dv = f"{data['parameterization']}@{data['version']}"
-            if dv not in result['potentials'][md5sum]['datasets']:
-                result['potentials'][md5sum]['datasets'].append(dv)
+            if dv not in result["potentials"][md5sum]["datasets"]:
+                result["potentials"][md5sum]["datasets"].append(dv)
 
             if el1 == el2:
-                sk_table = data['SK_table']
-                basis = sk_table['Basis']
-                shells = basis['Shells']
+                sk_table = data["SK_table"]
+                basis = sk_table["Basis"]
+                shells = basis["Shells"]
                 highest = shells.split()[-1][1]
-                if 'HubbDerivative' in basis:
-                    hder = basis['HubbDerivative']
+                if "HubbDerivative" in basis:
+                    hder = basis["HubbDerivative"]
                     elements[el1] = {
-                        'maximum angular momentum': highest,
-                        'Hubbard derivative': hder
+                        "maximum angular momentum": highest,
+                        "Hubbard derivative": hder,
                     }
                 else:
-                    elements[el1] = {
-                        'maximum angular momentum': highest
-                    }
-        result['datasets'][dataset]['element data'] = elements
+                    elements[el1] = {"maximum angular momentum": highest}
+        result["datasets"][dataset]["element data"] = elements
 
     # Print and save the results
     data = json.dumps(result, indent=4, sort_keys=True)
     # print(data)
-    with open('data/slako/metadata.json', 'w') as fd:
+    with open("data/slako/metadata.json", "w") as fd:
         fd.write(data)
 
 
